==> symfony_5.4.23+dfsg.orig.tar.xz: symfony-5.4.23/src/Symfony/Component/Intl/Resources/data/languages/mi.php <==
<?php

return [
    'Names' => [
        'ab' => 'Apakāhiana',
        'ace' => 'Akanīhi',
        'ada' => 'Atanga',
        'ady' => 'Āteke',
        'af' => 'Awherikāna',
        'agq' => 'Ākeme',
        'ain' => 'Ainu',
        'ak' => 'Ākana',
        'ale' => 'Ariuta',
        'alt' => 'Ātai ki te Tonga',
        'am' => 'Amahereka',
        'an' => 'Arakonihi',
        'ann' => 'Ōporo',
        'anp' => 'Anahika',
        'ar' => 'Ārapi',
        'arn' => 'Mapūte',
        'arp' => 'Arapaho',
        'ars' => 'Arapika Nahāri',
        'as' => 'Āhamēhi',
        'asa' => 'Ahu',
        'ast' => 'Ahitūriana',
        'atj' => 'Atikameke',
        'av' => 'Āwhāriki',
        'awa' => 'Āwati',
        'ay' => 'Aimāra',
        'az' => 'Ahapahāna',
        'ba' => 'Pākira',
        'ban' => 'Pārinīhi',
        'bas' => 'Pahā',
        'be' => 'Perarūhiana',
        'bem' => 'Pema',
        'bez' => 'Pena',
        'bg' => 'Pukēriana',
        'bho' => 'Pōhipuri',
        'bi' => 'Pihirāma',
        'bin' => 'Pini',
        'bla' => 'Hihika',
        'bm' => 'Pāpara',
        'bn' => 'Pāngara',
        'bo' => 'Tipete',
        'br' => 'Peretana',
        'brx' => 'Pōto',
        'bs' => 'Pōngiana',
        'bug' => 'Pukenīhi',
        'byn' => 'Pirina',
        'ca' => 'Katarana',
        'cay' => 'Keiuka',
        'ccp' => 'Tiakamā',
        'ce' => 'Tietiene',
        'ceb' => 'Hepuano',
        'cgg' => 'Tieka',
        'ch' => 'Tiamoro',
        'chk' => 'Tiukīhi',
        'chm' => 'Mari',
        'cho' => 'Tiokatō',
        'chp' => 'Tipiwaiana',
        'chr' => 'Tierokī',
        'chy' => 'Haiene',
        'ckb' => 'Te Puku o Kūrihi',
        'clc' => 'Tiekautini',
        'co' => 'Kohikana',
        'crg' => 'Mītiwhi',
        'crj' => 'Kirī Tonga-mā-Rāwhiti',
        'crk' => 'Parana Kirī',
        'crl' => 'Kirī Raki-mā-Rāwhiti',
        'crm' => 'Mū Kiri',
        'crr' => 'Arakōkiana Kararaina',
        'cs' => 'Tiekerowākiana',
        'csw' => 'Wāpi Kirī',
        'cv' => 'Tiuwhā',
        'cy' => 'Werehi',
        'da' => 'Teina',
        'dak' => 'Teikōta',
        'dar' => 'Tākawa',
        'dav' => 'Taita',
        'de' => 'Tiamana',
        'dgr' => 'Tōkiripi',
        'dje' => 'Tāma',
        'doi' => 'Tōkiri',
        'dsb' => 'Hōpiana Ōpaki',
        'dua' => 'Tuāra',
        'dv' => 'Tewhe',
        'dyo' => 'Hora-Whōni',
        'dz' => 'Tonoka',
        'dzg' => 'Tāhaka',
        'ebu' => 'Emepū',
        'ee' => 'Ewe',
        'efi' => 'Ewhiki',
        'eka' => 'Ekatika',
        'el' => 'Kiriki',
        'en' => 'Ingarihi',
        'eo' => 'Eheperāto',
        'es' => 'Pāniora',
        'et' => 'Ehetōniana',
        'eu' => 'Pāka',
        'ewo' => 'Ewāto',
        'fa' => 'Pāhiana',
        'ff' => 'Wharā',
        'fi' => 'Whinirānia',
        'fil' => 'Piripīno',
        'fj' => 'Whītīana',
        'fo' => 'Wharoīhi',
        'fon' => 'Whāna',
        'fr' => 'Wīwī',
        'frc' => 'Wīwī Keihana',
        'frr' => 'Whirīhiana ki te Raki',
        'fur' => 'Whiriūriana',
        'fy' => 'Whirīhiana ki te Uru',
        'ga' => 'Airihi',
        'gaa' => 'Kā',
        'gd' => 'Kotimana Keiriki',
        'gez' => 'Kīhi',
        'gil' => 'Kiripatīhi',
        'gl' => 'Karīhia',
        'gn' => 'Kuaranī',
        'gor' => 'Korōtaro',
        'gsw' => 'Tiamana Huiterangi',
        'gu' => 'Kutarāti',
        'guz' => 'Kūhī',
        'gv' => 'Manaki',
        'gwi' => 'Kuīti',
        'ha' => 'Hauha',
        'hai' => 'Haira',
        'haw' => 'Hawaiana',
        'hax' => 'Haira ki te Tonga',
        'he' => 'Hīperu',
        'hi' => 'Hīni',
        'hil' => 'Hirikeino',
        'hmn' => 'Mōnga',
        'hr' => 'Koroātiana',
        'hsb' => 'Hōpiana Ōkawa',
        'ht' => 'Haitiana Kereo',
        'hu' => 'Hanakariana',
        'hup' => 'Hupa',
        'hur' => 'Hekomerema',
        'hy' => 'Āmeiniana',
        'hz' => 'Herero',
        'ia' => 'Inarīngua',
        'iba' => 'Īpana',
        'ibb' => 'Ipīpio',
        'id' => 'Initonīhiana',
        'ig' => 'Ingo',
        'ii' => 'Hīhuana Eī',
        'ikt' => 'Inukitetū Kānata ki te Uru',
        'ilo' => 'Iroko',
        'inh' => 'Inguihi',
        'io' => 'Īto',
        'is' => 'Tiorangiana',
        'it' => 'Itāriana',
        'iu' => 'Inukitetū',
        'ja' => 'Hapanihi',
        'jbo' => 'Rōpāna',
        'jgo' => 'Nakōma',
        'jmc' => 'Mākame',
        'jv' => 'Hāwhanihi',
        'ka' => 'Hōriana',
        'kab' => 'Kapāio',
        'kac' => 'Kātiana',
        'kaj' => 'Hiu',
        'kam' => 'Kāmapa',
        'kbd' => 'Kapāriana',
        'kcg' => 'Tiapa',
        'kde' => 'Makonote',
        'kea' => 'Kapuwētianu',
        'kfo' => 'Koro',
        'kgp' => 'Keingāna',
        'kha' => 'Kahi',
        'khq' => 'Kōia Tīni',
        'ki' => 'Kikiu',
        'kj' => 'Kuiniāma',
        'kk' => 'Kahāka',
        'kkj' => 'Kako',
        'kl' => 'Karārihutu',
        'kln' => 'Karenini',
        'km' => 'Kimei',
        'kmb' => 'Kimipunu',
        'kn' => 'Kanara',
        'ko' => 'Kōreana',
        'kok' => 'Kōkani',
        'kpe' => 'Kepere',
        'kr' => 'Kanuri',
        'krc' => 'Karatai-Pāka',
        'krl' => 'Kareriana',
        'kru' => 'Kurā',
        'ks' => 'Kahimiri',
        'ksb' => 'Hapāra',
        'ksf' => 'Pāwhia',
        'ksh' => 'Korōniana',
        'ku' => 'Kūrihi',
        'kum' => 'Kumiki',
        'kv' => 'Komi',
        'kw' => 'Kōnihi',
        'kwk' => 'Kuakawara',
        'ky' => 'Kēkete',
        'la' => 'Rātini',
        'lad' => 'Ratino',
        'lag' => 'Rangi',
        'lb' => 'Rakimipēkihi',
        'lez' => 'Rēhiana',
        'lg' => 'Kanāta',
        'li' => 'Ripēkuehe',
        'lil' => 'Rirūete',
        'lkt' => 'Rakota',
        'ln' => 'Ringarā',
        'lo' => 'Rao',
        'lou' => 'Ruīhana Kereo',
        'loz' => 'Rauhi',
        'lrc' => 'Ruri ki te Raki',
        'lsm' => 'Hāmia',
        'lt' => 'Rihuainiana',
        'lu' => 'Rupa Katanga',
        'lua' => 'Rupa Rurua',
        'lun' => 'Runa',
        'luo' => 'Ruo',
        'lus' => 'Mīho',
        'luy' => 'Rūia',
        'lv' => 'Rātiana',
        'mad' => 'Matuirīhi',
        'mag' => 'Makāhi',
        'mai' => 'Maitiri',
        'mak' => 'Makahā',
        'mas' => 'Māhai',
        'mdf' => 'Mōkaha',
        'men' => 'Menēte',
        'mer' => 'Meru',
        'mfe' => 'Morihiene',
        'mg' => 'Marakāhi',
        'mgh' => 'Makuwa-Mēto',
        'mgo' => 'Meta',
        'mh' => 'Mararīhi',
        'mi' => 'Māori',
        'mic' => 'Mīkamā',
        'min' => 'Minākapao',
        'mk' => 'Makatōniana',
        'ml' => 'Mareiarama',
        'mn' => 'Mongōriana',
        'mni' => 'Manipuri',
        'moe' => 'Inu-aimuna',
        'moh' => 'Mauhōka',
        'mos' => 'Mohī',
        'mr' => 'Marati',
        'ms' => 'Marei',
        'mt' => 'Mōtīhi',
        'mua' => 'Mūtanga',
        'mus' => 'Mukōki',
        'mwl' => 'Miranatīhi',
        'my' => 'Pūmīhī',
        'myv' => 'Erehīa',
        'mzn' => 'Mahaterani',
        'na' => 'Nauru',
        'nap' => 'Neaporitana',
        'naq' => 'Nama',
        'nb' => 'Pakamō Nōwītiana',
        'nd' => 'Enetepēra ki te Raki',
        'nds' => 'Tiamana Ōpaki',
        'ne' => 'Nepari',
        'new' => 'Newari',
        'ng' => 'Natōka',
        'nia' => 'Niēhe',
        'niu' => 'Niueana',
        'nl' => 'Tati',
        'nmg' => 'Kuatio',
        'nn' => 'Nīnōka Nōwītiana',
        'nnh' => 'Nekeipū',
        'no' => 'Nōwītiana',
        'nog' => 'Nōkai',
        'nqo' => 'Unukō',
        'nr' => 'Enetepēra ki te Tonga',
        'nso' => 'Hoto ki te Raki',
        'nus' => 'Nua',
        'nv' => 'Nawahō',
        'ny' => 'Nānia',
        'nyn' => 'Nānakore',
        'oc' => 'Ōkitana',
        'ojb' => 'Ōtīpia Raki-mā-Uru',
        'ojc' => 'Te Puku o Ōhiwa',
        'ojs' => 'Ōti-Kirī',
        'ojw' => 'Ōhīpiwa ki te Uru',
        'oka' => 'Ōkanakana',
        'om' => 'Ōromo',
        'or' => 'Ōtia',
        'os' => 'Ōtītiki',
        'pa' => 'Punutapi',
        'pag' => 'Pāngahina',
        'pam' => 'Pamapaka',
        'pap' => 'Papiamēto',
        'pau' => 'Parauna',
        'pcm' => 'Ngāitiriana Kōrapurapu',
        'pis' => 'Pītini',
        'pl' => 'Pōrīhi',
        'pqm' => 'Marahiti-Pehamakoare',
        'ps' => 'Pātio',
        'pt' => 'Pōtukīhi',
        'qu' => 'Kētua',
        'rap' => 'Rapanui',
        'rar' => 'Rarotonga',
        'rhg' => 'Rohingia',
        'rm' => 'Romānihi',
        'rn' => 'Rūniti',
        'ro' => 'Romēniana',
        'rof' => 'Romopo',
        'ru' => 'Ruhiana',
        'rup' => 'Aromeiniana',
        'rw' => 'Kiniawāna',
        'rwk' => 'Rawa',
        'sa' => 'Hanahiti',
        'sad' => 'Hātawe',
        'sah' => 'Hakā',
        'saq' => 'Hāpuru',
        'sat' => 'Hātari',
        'sba' => 'Nekāpei',
        'sbp' => 'Hāngu',
        'sc' => 'Hātīriana',
        'scn' => 'Hihiriana',
        'sco' => 'Kotimana',
        'sd' => 'Hiniti',
        'se' => 'Hami ki te Raki',
        'seh' => 'Hena',
        'ses' => 'Kōiaporo Heni',
        'sg' => 'Hāngo',
        'shi' => 'Tahere',
        'shn' => 'Hāna',
        'si' => 'Hinihāra',
        'sk' => 'Horowākia',
        'sl' => 'Horowēniana',
        'slh' => 'Ratūti ki te Tonga',
        'sm' => 'Hāmoa',
        'smn' => 'Inari Hami',
        'sms' => 'Hakoto Hāmi',
        'sn' => 'Hōna',
        'snk' => 'Honīke',
        'so' => 'Hamāri',
        'sq' => 'Arapeiniana',
        'sr' => 'Hēpiana',
        'srn' => 'Harāna Tongo',
        'ss' => 'Wāti',
        'st' => 'Hōto ki te Tonga',
        'str' => 'Terete Hārihi',
        'su' => 'Hunanīhi',
        'suk' => 'Hukuma',
        'sv' => 'Huīteneana',
        'sw' => 'Wāhīri',
        'swb' => 'Komōriana',
        'syr' => 'Hīriaka',
        'ta' => 'Tamira',
        'tce' => 'Tatōne ki te Tonga',
        'te' => 'Teruku',
        'tem' => 'Tīmene',
        'teo' => 'Teho',
        'tet' => 'Tetumu',
        'tg' => 'Tāhiki',
        'tgx' => 'Tēkihi',
        'th' => 'Tai',
        'tht' => 'Tātana',
        'ti' => 'Tekirina',
        'tig' => 'Tīkara',
        'tk' => 'Tākamana',
        'tlh' => 'Kirionga',
        'tli' => 'Tirīkiti',
        'tn' => 'Hawāna',
        'to' => 'Tonga',
        'tok' => 'Toki Pona',
        'tpi' => 'Toko Pīhini',
        'tr' => 'Tākei',
        'trv' => 'Taroko',
        'ts' => 'Honga',
        'tt' => 'Tatā',
        'ttm' => 'Tūtone ki te Raki',
        'tum' => 'Tūmuka',
        'tvl' => 'Tuwaru',
        'twq' => 'Tahawaka',
        'ty' => 'Tahiti',
        'tyv' => 'Tuwīniana',
        'tzm' => 'Te Puku o Atarihi Tamahēte',
        'udm' => 'Ūmutu',
        'ug' => 'Wīkura',
        'uk' => 'Ukarainiana',
        'umb' => 'Ūpunu',
        'ur' => 'Ūru',
        'uz' => 'Ūpeke',
        'vai' => 'Wai',
        've' => 'Wenēra',
        'vi' => 'Witināmiana',
        'vun' => 'Wāhau',
        'wa' => 'Warūna',
        'wae' => 'Wāhere',
        'wal' => 'Wareita',
        'war' => 'Warei',
        'wo' => 'Warawhe',
        'wuu' => 'Hainamana Wū',
        'xal' => 'Karamiki',
        'xh' => 'Tōha',
        'xog' => 'Hoka',
        'yav' => 'Angapene',
        'ybb' => 'Emapa',
        'yi' => 'Irihi',
        'yo' => 'Ōrūpa',
        'yrl' => 'Nīkātū',
        'yue' => 'Katonīhi',
        'zgh' => 'Moroko Tamatai',
        'zh' => 'Hainamana',
        'zu' => 'Tūru',
        'zun' => 'Tuni',
        'zza' => 'Tātā',
    ],
    'LocalizedNames' => [
        'ar_001' => 'Ārapi Moroki',
        'de_AT' => 'Tiamana Ateriana',
        'de_CH' => 'Tiamana Ōkawa Huiterangi',
        'en_AU' => 'Ingarihi Ahitereiriana',
        'en_CA' => 'Ingarihi Kānata',
        'en_GB' => 'Ingarihi Piritene',
        'en_US' => 'Ingarihi Amerikana',
        'es_419' => 'Pāniora Amerikana ki te Tonga',
        'es_ES' => 'Pāniora Ūropi',
        'es_MX' => 'Pāniora Mehikana',
        'fa_AF' => 'Tari',
        'fr_CA' => 'Wīwī Kānata',
        'fr_CH' => 'Wīwī Huiterangi',
        'nl_BE' => 'Tati Whēmirihi',
        'pt_BR' => 'Pōtukīhi Parahi',
        'pt_PT' => 'Pōtukīhi Uropi',
        'zh_Hans' => 'Hainamana Māmā',
        'zh_Hant' => 'Hainamana Tukuiho',
    ],
];

==> symfony_6.4.5+dfsg.orig.tar.xz: symfony-6.4.5/src/Symfony/Component/Intl/Resources/data/languages/mi.php <==
<?php

return [
    'Names' => [
        'ab' => 'Apakāhiana',
        'ace' => 'Akanīhi',
        'ada' => 'Atāngami',
        'ady' => 'Āteke',
        'af' => 'Awherikāna',
        'agq' => 'Ākeme',
        'ain' => 'Ainu',
        'ak' => 'Ākana',
        'ale' => 'Ariuta',
        'alt' => 'Ātai ki te Tonga',
        'am' => 'Amahereka',
        'an' => 'Arakonihi',
        'ann' => 'Ōporo',
        'anp' => 'Anahika',
        'ar' => 'Ārapi',
        'arn' => 'Mapūte',
        'arp' => 'Arapaho',
        'ars' => 'Arapika Nahāri',
        'as' => 'Āhamēhi',
        'asa' => 'Ahu',
        'ast' => 'Ahitūriana',
        'atj' => 'Atikameke',
        'av' => 'Āwhāriki',
        'awa' => 'Awāti',
        'ay' => 'Aimāra',
        'az' => 'Atepaihānia',
        'ba' => 'Pākīra',
        'ban' => 'Pārinīhi',
        'bas' => 'Pahā',
        'be' => 'Perarūhiana',
        'bem' => 'Pema',
        'bez' => 'Pena',
        'bg' => 'Purukāriana',
        'bgc' => 'Herianawhi',
        'bho' => 'Pōhipuri',
        'bi' => 'Pihirāma',
        'bin' => 'Pini',
        'bla' => 'Hihika',
        'bm' => 'Pāpara',
        'bn' => 'Pākara',
        'bo' => 'Tipete',
        'br' => 'Peretana',
        'brx' => 'Pōto',
        'bs' => 'Pōngiana',
        'bug' => 'Pukenīhi',
        'byn' => 'Pirina',
        'ca' => 'Katarana',
        'cay' => 'Keiūka',
        'ccp' => 'Tiakamā',
        'ce' => 'Tietiene',
        'ceb' => 'Hepuano',
        'cgg' => 'Tieka',
        'ch' => 'Tiamoro',
        'chk' => 'Tiukīhi',
        'chm' => 'Mari',
        'cho' => 'Tiokatō',
        'chp' => 'Tiepewaiana',
        'chr' => 'Tierokī',
        'chy' => 'Haiene',
        'ckb' => 'Kūrihi Waenga',
        'clc' => 'Tiekautini',
        'co' => 'Kōhikana',
        'crg' => 'Mītiwhi',
        'crj' => 'Kirī Tonga-mā-Rāwhiti',
        'crk' => 'Pareina Kirī',
        'crl' => 'Kirī Raki-mā-Rāwhiti',
        'crm' => 'Mūhi Kirī',
        'crr' => 'Arakōkiana Kararaina',
        'cs' => 'Tieke',
        'csw' => 'Wāpi Kirī',
        'cv' => 'Tiuwhāhi',
        'cy' => 'Werehi',
        'da' => 'Teina',
        'dak' => 'Takōta',
        'dar' => 'Tākawa',
        'dav' => 'Taita',
        'de' => 'Tiamana',
        'dgr' => 'Tōkiripi',
        'dje' => 'Tāma',
        'doi' => 'Tōkiri',
        'dsb' => 'Hōpiana Hakahaka',
        'dua' => 'Tuāra',
        'dv' => 'Tīwhehi',
        'dyo' => 'Hora-Whōni',
        'dz' => 'Tonoka',
        'dzg' => 'Tahāka',
        'ebu' => 'Emepū',
        'ee' => 'Ewe',
        'efi' => 'Ewhiki',
        'eka' => 'Ekatika',
        'el' => 'Kariki',
        'en' => 'Ingarihi',
        'eo' => 'Eheperāto',
        'es' => 'Pāniora',
        'et' => 'Etōniana',
        'eu' => 'Pākihi',
        'ewo' => 'Ewāto',
        'fa' => 'Pāhiana',
        'ff' => 'Whūra',
        'fi' => 'Whinirānia',
        'fil' => 'Piripīno',
        'fj' => 'Whītīana',
        'fo' => 'Wharoīhi',
        'fon' => 'Whāna',
        'fr' => 'Wīwī',
        'frc' => 'Wīwī Keihana',
        'frr' => 'Whirīhiana ki te Raki',
        'fur' => 'Whiriūriana',
        'fy' => 'Whirīhiana ki te Uru',
        'ga' => 'Airihi',
        'gaa' => 'Kā',
        'gd' => 'Keiriki Kotimana',
        'gez' => 'Kīhi',
        'gil' => 'Kiripatīhi',
        'gl' => 'Karīhia',
        'gn' => 'Kuaranī',
        'gor' => 'Korōtaro',
        'gsw' => 'Tiamana Huiterangi',
        'gu' => 'Kutarāti',
        'guz' => 'Kūhī',
        'gv' => 'Manaki',
        'gwi' => 'Kuitīna',
        'ha' => 'Hauha',
        'hai' => 'Heira',
        'haw' => 'Wāhu',
        'hax' => 'Haira ki te Tonga',
        'he' => 'Hīperu',
        'hi' => 'Hīni',
        'hil' => 'Hirikaina',
        'hmn' => 'Mōnga',
        'hr' => 'Koroātiana',
        'hsb' => 'Hōpiana Maunga',
        'ht' => 'Kereō Haiti',
        'hu' => 'Hanekari',
        'hup' => 'Hupa',
        'hur' => 'Hākomerema',
        'hy' => 'Āmeniana',
        'hz' => 'Herero',
        'ia' => 'Inarīngua',
        'iba' => 'Īpana',
        'ibb' => 'Ipīpio',
        'id' => 'Initonīhiana',
        'ig' => 'Ikapo',
        'ii' => 'Hīhuana Eī',
        'ikt' => 'Inukitetūta Kānata ki te Uru',
        'ilo' => 'Iroko',
        'inh' => 'Inguihi',
        'io' => 'Īto',
        'is' => 'Tiorangi',
        'it' => 'Itāriana',
        'iu' => 'Inukitetūta',
        'ja' => 'Hapanihi',
        'jbo' => 'Rōpāna',
        'jgo' => 'Nakōma',
        'jmc' => 'Mākame',
        'jv' => 'Hāwhanihi',
        'ka' => 'Hōriana',
        'kab' => 'Kapāiro',
        'kac' => 'Katīana',
        'kaj' => 'Heiho',
        'kam' => 'Kāmapa',
        'kbd' => 'Kapāriana',
        'kcg' => 'Tiapa',
        'kde' => 'Makonote',
        'kea' => 'Kapuwētianu',
        'kfo' => 'Koro',
        'kgp' => 'Keinganga',
        'kha' => 'Kahi',
        'khq' => 'Kōira Tīni',
        'ki' => 'Kikūiu',
        'kj' => 'Kuoniāma',
        'kk' => 'Kahāka',
        'kkj' => 'Kako',
        'kl' => 'Kararīhutu',
        'kln' => 'Karenini',
        'km' => 'Kimēra',
        'kmb' => 'Kimipunu',
        'kn' => 'Kanara',
        'ko' => 'Kōreana',
        'kok' => 'Kōkani',
        'kpe' => 'Kepēre',
        'kr' => 'Kanuri',
        'krc' => 'Karatai-Pāka',
        'krl' => 'Kareriana',
        'kru' => 'Kuruka',
        'ks' => 'Kahimiri',
        'ksb' => 'Hapāra',
        'ksf' => 'Pāwhia',
        'ksh' => 'Korōniana',
        'ku' => 'Kūrihi',
        'kum' => 'Kumiki',
        'kv' => 'Komi',
        'kw' => 'Kōnihi',
        'kwk' => 'Kuakawara',
        'ky' => 'Kiakihi',
        'la' => 'Rātini',
        'lad' => 'Ratino',
        'lag' => 'Rangi',
        'lb' => 'Rakapuō',
        'lez' => 'Rēhiana',
        'lg' => 'Kānata',
        'li' => 'Ripūkuihi',
        'lil' => 'Riruete',
        'lkt' => 'Rakōta',
        'ln' => 'Ringāra',
        'lo' => 'Rao',
        'lou' => 'Kreōro Ruihiana',
        'loz' => 'Rohi',
        'lrc' => 'Ruri ki te Raki',
        'lsm' => 'Hāmia',
        'lt' => 'Rituānia',
        'lu' => 'Rupa Katanga',
        'lua' => 'Rupa Rurua',
        'lun' => 'Runa',
        'luo' => 'Ruo',
        'lus' => 'Mīho',
        'luy' => 'Rūia',
        'lv' => 'Rāwhia',
        'mad' => 'Maturīhi',
        'mag' => 'Makāhi',
        'mai' => 'Maitiri',
        'mak' => 'Makahā',
        'mas' => 'Māhai',
        'mdf' => 'Mōkaha',
        'men' => 'Menēte',
        'mer' => 'Meru',
        'mfe' => 'Morihiene',
        'mg' => 'Marakāhi',
        'mgh' => 'Makuwa-Mēto',
        'mgo' => 'Meta',
        'mh' => 'Mararīhi',
        'mi' => 'Māori',
        'mic' => 'Mīkamā',
        'min' => 'Minākapao',
        'mk' => 'Makerōnia',
        'ml' => 'Mareiārama',
        'mn' => 'Mongōria',
        'mni' => 'Manipuri',
        'moe' => 'Inu-aimuna',
        'moh' => 'Mauhōka',
        'mos' => 'Mohi',
        'mr' => 'Marati',
        'ms' => 'Marei',
        'mt' => 'Mārata',
        'mua' => 'Mūnatanga',
        'mus' => 'Mukōki',
        'mwl' => 'Miranatīhi',
        'my' => 'Pēmīhi',
        'myv' => 'Erehīa',
        'mzn' => 'Mahaterani',
        'na' => 'Nauru',
        'nap' => 'Neaporitana',
        'naq' => 'Nama',
        'nb' => 'Pakamō Nōwei',
        'nd' => 'Enetepēra ki te Raki',
        'nds' => 'Tiamana Hakahaka',
        'ne' => 'Nepari',
        'new' => 'Newari',
        'ng' => 'Natōka',
        'nia' => 'Niāhi',
        'niu' => 'Niueana',
        'nl' => 'Tati',
        'nmg' => 'Kuahio',
        'nn' => 'Nīnōka Nōwei',
        'nnh' => 'Nekiepūna',
        'no' => 'Nōwei',
        'nog' => 'Nōkai',
        'nqo' => 'Unukō',
        'nr' => 'Enetepēra ki te Tonga',
        'nso' => 'Hoto ki te Raki',
        'nus' => 'Nua',
        'nv' => 'Nawahō',
        'ny' => 'Niānia',
        'nyn' => 'Niānakore',
        'oc' => 'Ōkitana',
        'ojb' => 'Ōtīpia Raki-mā-Uru',
        'ojc' => 'Ohīpawe Waenga',
        'ojs' => 'Ōti-Kirī',
        'ojw' => 'Ōhīpiwa ki te Uru',
        'oka' => 'Ōkanakana',
        'om' => 'Ōromo',
        'or' => 'Ōtia',
        'os' => 'Ōtītiki',
        'pa' => 'Punutapi',
        'pag' => 'Pāngahina',
        'pam' => 'Pamapaka',
        'pap' => 'Papiamēto',
        'pau' => 'Pārau',
        'pcm' => 'Ngāitiriana Kōrapurapu',
        'pis' => 'Pītini',
        'pl' => 'Pōrihi',
        'pqm' => 'Marahiti-Pehamakoare',
        'ps' => 'Pāhitō',
        'pt' => 'Pōtukīhi',
        'qu' => 'Kētua',
        'raj' => 'Ratiahitani',
        'rap' => 'Rapanui',
        'rar' => 'Rarotonga',
        'rhg' => 'Rohingia',
        'rm' => 'Romānihi',
        'rn' => 'Rūniti',
        'ro' => 'Romeinia',
        'rof' => 'Romopo',
        'ru' => 'Ruhiana',
        'rup' => 'Aromeiniana',
        'rw' => 'Kiniawāna',
        'rwk' => 'Rawa',
        'sa' => 'Hanahiti',
        'sad' => 'Hātawe',
        'sah' => 'Hakūta',
        'saq' => 'Hāmapuru',
        'sat' => 'Hatāri',
        'sba' => 'Nekāpei',
        'sbp' => 'Hāngu',
        'sc' => 'Hārinia',
        'scn' => 'Hihiriana',
        'sco' => 'Kotimana',
        'sd' => 'Hiniti',
        'se' => 'Hami ki te Raki',
        'seh' => 'Hena',
        'ses' => 'Kōiraporo Heni',
        'sg' => 'Hāngo',
        'shi' => 'Tāhehita',
        'shn' => 'Hāna',
        'si' => 'Hinihāra',
        'sk' => 'Horowākia',
        'sl' => 'Horowinia',
        'slh' => 'Ratūti ki te Tonga',
        'sm' => 'Hāmoa',
        'smn' => 'Inari Hami',
        'sms' => 'Hakoto Hāmi',
        'sn' => 'Hōna',
        'snk' => 'Honīke',
        'so' => 'Hamāri',
        'sq' => 'Arapeiniana',
        'sr' => 'Hirupia',
        'srn' => 'Harāna Tongo',
        'ss' => 'Wāti',
        'st' => 'Hōto ki te Tonga',
        'str' => 'Hārihi Kuititanga',
        'su' => 'Hunanīhi',
        'suk' => 'Hukuma',
        'sv' => 'Huitene',
        'sw' => 'Wāhīri',
        'swb' => 'Komōriana',
        'syr' => 'Hīriaka',
        'ta' => 'Tamira',
        'tce' => 'Tatōne ki te Tonga',
        'te' => 'Teruku',
        'tem' => 'Tīmene',
        'teo' => 'Teho',
        'tet' => 'Tetumu',
        'tg' => 'Tāhiki',
        'tgx' => 'Tākihi',
        'th' => 'Tai',
        'tht' => 'Tātana',
        'ti' => 'Tekirinia',
        'tig' => 'Tīkara',
        'tk' => 'Tākamana',
        'tlh' => 'Kirīngona',
        'tli' => 'Tirīkiti',
        'tn' => 'Hawāna',
        'to' => 'Tonga',
        'tok' => 'Toki Pona',
        'tpi' => 'Toko Pīhini',
        'tr' => 'Tākei',
        'trv' => 'Taroko',
        'ts' => 'Honga',
        'tt' => 'Tatā',
        'ttm' => 'Tūtone ki te Raki',
        'tum' => 'Tumūka',
        'tvl' => 'Tuwaru',
        'twq' => 'Tahawaka',
        'ty' => 'Tahiti',
        'tyv' => 'Tuwīniana',
        'tzm' => 'Tamahīta Te Puku o Atarihi',
        'udm' => 'Ūmutu',
        'ug' => 'Wīkura',
        'uk' => 'Ukareinga',
        'umb' => 'Ūpunu',
        'ur' => 'Ūrutu',
        'uz' => 'Ūpeke',
        'vai' => 'Wai',
        've' => 'Wēnera',
        'vi' => 'Whitināmu',
        'vun' => 'Whunio',
        'wa' => 'Warūna',
        'wae' => 'Wāhere',
        'wal' => 'Wareita',
        'war' => 'Warei',
        'wo' => 'Warawhe',
        'wuu' => 'Hainamana Wū',
        'xal' => 'Karamiki',
        'xh' => 'Tōha',
        'xog' => 'Hoka',
        'yav' => 'Angapene',
        'ybb' => 'Emapa',
        'yi' => 'Irihi',
        'yo' => 'Ōrūpa',
        'yrl' => 'Nīkātū',
        'yue' => 'Katonīhi',
        'zgh' => 'Moroko Tamatai',
        'zh' => 'Hainamana',
        'zu' => 'Tūru',
        'zun' => 'Tuni',
        'zza' => 'Tātā',
    ],
    'LocalizedNames' => [
        'ar_001' => 'Ārapi Moroko',
        'de_AT' => 'Tiamana Ateriana',
        'de_CH' => 'Tiamana Ōkawa Huiterangi',
        'en_AU' => 'Ingarihi Ahitereiriana',
        'en_CA' => 'Ingarihi Kānata',
        'en_GB' => 'Ingarihi Piritene',
        'en_US' => 'Ingarihi Amerikana',
        'es_419' => 'Pāniora Amerikana ki te Tonga',
        'es_ES' => 'Pāniora Ūropi',
        'es_MX' => 'Pāniora Mehikana',
        'fa_AF' => 'Tāri',
        'fr_CA' => 'Wīwī Kānata',
        'fr_CH' => 'Wīwī Huiterangi',
        'nl_BE' => 'Tati Whēmirihi',
        'pt_BR' => 'Pōtukīhi Parahi',
        'pt_PT' => 'Pōtukīhi Uropi',
        'zh_Hans' => 'Hainamana Māmā',
        'zh_Hant' => 'Hainamana Tukuiho',
    ],
];
